searchNodes=[{"doc":"A composite calendar is one in which a certain range of dates is interpreted in one calendar and a different range of dates is interpreted in a different calendar. The canonical example is the transition from the Julian to Gregorian calendar for European countries during the 16th to 20th centuries. A configuration is simply a list of dates in the the appropriate calendar indicating when the calendar transitions occur. For example, assuming England moved from the Julian to Gregorian calendar on 14th of September, 1752 Gregorian then the configuration would be: defmodule Cldr.Calendar.England do use Cldr.Calendar.Composite , calendars : [ ~D[1752-09-14 Cldr.Calendar.Gregorian] ] , base_calendar : Cldr.Calendar.Julian end The :base_calendar option indicates the calendar in use before any other configured calendars. The default is Cldr.Calendar.Julian . Julian to Gregorian transition One of the uses of this calendar is to define a calendar that reflects the transition from the Julian to the Gregorian calendar. Applicable primarily to western european countries and related colonies, the transition to the Gregorian calendar occurred between the 16th and 20th centuries. One strong reference is the Perpetual Calendar site maintained by Toke Nørby . An additional source of information is Wikipedia . Multiple compositions A more complex example composes more than one calendar. For example, Egypt used the Coptic calendar from 238 BCE until Rome introduced the Julian calendar in approximately 30 BCE. The Gregorian calendar was then introduced in 1875. Although the exact dates of introduction aren't known we can approximate the composition of calendars with: defmodule Cldr.Calendar.Composite.Egypt do use Cldr.Calendar.Composite , calendars : [ ~D[-0045-01-01 Cldr.Calendar.Julian] , ~D[1875-09-01] ] , base_calendar : Cldr.Calendar.Coptic end","ref":"Cldr.Calendar.Composite.html","title":"Cldr.Calendar.Composite","type":"module"},{"doc":"Creates a new composite compiler. Arguments calendar_module is any module name. This will be the name of the composite calendar if it is successfully created. options is a keyword list of options. Options :calendars is a list of dates representing the first new date at which a calendar is introduced. These dates should be expressed in the calendar of the new period. :base_calendar is any calendar module that is used as the calendar for any dates prior to the first transition. The default is Cldr.Calendar.Julian . Returns {:ok, module} or {:module_already_exists, calendar_module} Examples iex&gt; Cldr.Calendar.Composite . new Cldr.Calendar.Denmark , ...&gt; calendars : ~D[1700-03-01 Cldr.Calendar.Gregorian] { :ok , Cldr.Calendar.Denmark }","ref":"Cldr.Calendar.Composite.html#new/2","title":"Cldr.Calendar.Composite.new/2","type":"function"},{"doc":"","ref":"Cldr.Calendar.Composite.Compiler.html","title":"Cldr.Calendar.Composite.Compiler","type":"module"},{"doc":"Most calendar implementations in computer software implement the Proleptic Gregorian Calendar which projects the Gregorian Calendar backwards before its introduction starting in 1582. In general use today this is acceptable since it is not common to be working with dates prior to this period. However for certain fields of study, the proleptic calendar is misleading. A letter or document dated in 1751 in England would be a date in the Julian Calendar since the Gregorian calendar wasn't introduced in England and its colonies until September 14th, 1752. This results in dates being 11 days later in the Gregorian calendar at this time compared with the Julian calendar. Calendars defined with this library support composing multiple calendars that are implemented for different time periods. While multiple calendars can be composed, the primary use case is to compose calendars that represent a continuum from the Julian calendar to the Gregorian calendar. Calendars defined with this library implement the Calendar behaviour and the Cldr.Calendar behaviour defined in the library ex_cldr_calendars . See Cldr.Calendar for further information.","ref":"readme.html","title":"Cldr Composite Calendars","type":"extras"},{"doc":"A composite calendar is definted as a series of compositions reprenting the transition from one calendar to another. For the example of the transition from Julian to Gregorian calendar in England the first date of the Gregorian calendar is September 14th, 1752. defmodule England do use Cldr.Calendar.Composite , calendars : ~D[1752-09-14] , base_calendar : Cldr.Calendar.Julian end This configuration states that September 14th, 1752 is the first day in the Gregorian calendar. The :base_calendar defines the calendar in use before any other composed calendar. Since Cldr.Calendar.Julian is the default :base_calendar , this option may be omitted resulting in the following configuration: defmodule England do use Cldr.Calendar.Composite , calendars : ~D[1752-09-14] end It is also possible to define new composite calendars at runtime as well: iex&gt; Cldr.Calendar.Composite . new France , calendars : ~D[1582-12-20] { :ok , France } A more complex example composes more than one calendar. For example, Egypt used the Coptic calendar from 238 BCE until Rome introduced the Julian calendar in approximately 30 BCE. The Gregorian calendar was then introduced in 1875. Although the exact dates of introduction aren't known we can approximate the composition of calendars with: defmodule Cldr.Calendar.Composite.Egypt do use Cldr.Calendar.Composite , calendars : [ ~D[-0045-01-01 Cldr.Calendar.Julian] , ~D[1875-09-01] ] , base_calendar : Cldr.Calendar.Coptic end","ref":"readme.html#defining-a-composite-calendar","title":"Cldr Composite Calendars - Defining a Composite Calendar","type":"extras"},{"doc":"Add cldr_calendars_composite to your list of dependencies in mix.exs . def deps do [ { :cldr_calendars_composite , &quot;~&gt; 0.1.0&quot; } ] end Documentation is published at https://hexdocs.pm/cldr_calendars_composite .","ref":"readme.html#installation","title":"Cldr Composite Calendars - Installation","type":"extras"},{"doc":"","ref":"changelog.html","title":"Changelog","type":"extras"},{"doc":"This is the changelog for Cldr Calendars Composite Calendars Composite v1.0.0 released on April 28th, 2023. For older changelogs please consult the release tag on GitHub ** Note that ex_cldr_calendars_composite is support on Elixir 1.10 and later only. Bug Fixes Add required days_in_month/1 callback.","ref":"changelog.html#cldr-calendars-composite-v1-0-0","title":"Changelog - Cldr Calendars Composite  v1.0.0","type":"extras"},{"doc":"This is the changelog for Cldr Calendars Composite v0.2.0 released on December 16th, 2021. For older changelogs please consult the release tag on GitHub ** Note that ex_cldr_calendars_composite is support on Elixir 1.10 and later only. Bug Fixes Fix compatibility with ex_cldr_calendars version 1.17 and later which have an updated behaviour specification.","ref":"changelog.html#cldr-calendars-composite-v0-3-0","title":"Changelog - Cldr Calendars Composite  v0.3.0","type":"extras"},{"doc":"This is the changelog for Cldr Calendars Composite v0.2.0 released on May 22nd, 2021. For older changelogs please consult the release tag on GitHub Bug Fixes Remove warnings for Elixir 1.12","ref":"changelog.html#cldr-calendars-composite-v0-2-0","title":"Changelog - Cldr Calendars Composite  v0.2.0","type":"extras"},{"doc":"This is the changelog for Cldr Calendars Composite v0.1.0 released on June 20th, 2020. For older changelogs please consult the release tag on GitHub Enhancements Initial release.","ref":"changelog.html#cldr-calendars-composite-v0-1-0","title":"Changelog - Cldr Calendars Composite  v0.1.0","type":"extras"},{"doc":"Copyright 2018-2020 Kip Cole Licensed under the Apache License, Version 2.0 (the &quot;License&quot;); you may not use this file except in compliance with the License. You may obtain a copy of the License at http :// www . apache . org / licenses / LICENSE - 2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an &quot;AS IS&quot; BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.","ref":"license.html","title":"License","type":"extras"}]